# FAQ

Frequently asked questions about erk.

<!-- TODO: This document is a skeleton. Fill in the sections below. -->

## General

<!-- TODO: General questions about erk -->

### What is erk?

<!-- TODO: Brief explanation -->

### Do I need an IDE?

<!-- TODO: IDE-free workflow explanation -->

### What's a plan?

<!-- TODO: Explain plans -->

## Setup

<!-- TODO: Setup-related questions -->

### Which tools are required?

<!-- TODO: Link to prerequisites -->

### How do I update erk?

<!-- TODO: Update instructions -->

## Workflow

<!-- TODO: Workflow questions -->

### When should I use planning vs planless?

<!-- TODO: Decision criteria -->

### Can I use erk with an existing PR?

<!-- TODO: PR checkout workflow -->

### How do I handle conflicts?

<!-- TODO: Conflict resolution -->

## Troubleshooting

<!-- TODO: Quick troubleshooting -->

### Commands don't change my directory

<!-- TODO: Shell integration -->

### erk doctor shows errors

<!-- TODO: Common doctor errors -->

## See Also

- [FAQ](README.md) - Detailed troubleshooting guides
- [Getting Started](../tutorials/) - Setup guides
